@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Array;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.053003';
+our $VERSION   = '0.053004';
 
 use Exporter::Tiny;
 use Sub::HandlesVia::HandlerLibrary;
@@ -1124,6 +1124,41 @@ sub not_all_true {
 		usage     => '$coderef',
 		template  => '&List::Util::notall($ARG, @{$GET})',
 		documentation => 'Like C<< List::Util::notall() >>.',
+		xs_install => sub {
+			my ( $handler, %args ) = @_;
+			my %info = %{ $args{info} };
+			if ( $handler->curried and @{$handler->curried}==1 and CodeRef->check($handler->curried->[0]) ) {
+				$info{callback} = $handler->curried->[0];
+			}
+			elsif ( $handler->curried and @{$handler->curried} ) {
+				die;
+			}
+			Sub::HandlesVia::XS::INSTALL_shvxs_array_not_all_true( $args{fqname}, \%info );
+			return 1;
+		},
+}
+
+sub none {
+	require List::Util;
+	handler
+		name      => 'Array:none',
+		args      => 1,
+		signature => [CodeRef],
+		usage     => '$coderef',
+		template  => '&List::Util::none($ARG, @{$GET})',
+		documentation => 'Like C<< List::Util::none() >>.',
+		xs_install => sub {
+			my ( $handler, %args ) = @_;
+			my %info = %{ $args{info} };
+			if ( $handler->curried and @{$handler->curried}==1 and CodeRef->check($handler->curried->[0]) ) {
+				$info{callback} = $handler->curried->[0];
+			}
+			elsif ( $handler->curried and @{$handler->curried} ) {
+				die;
+			}
+			Sub::HandlesVia::XS::INSTALL_shvxs_array_none( $args{fqname}, \%info );
+			return 1;
+		},
 }
 
 sub min {
